==============================
Tasks instruments
==============================

BuildInstrument
----------------

.. autoclass:: exorad.tasks.instrumentHandler.BuildInstrument
    :members:
    :undoc-members:
    :show-inheritance:

BuildChannels
----------------

.. autoclass:: exorad.tasks.instrumentHandler.BuildChannels
    :members:
    :undoc-members:
    :show-inheritance:

LoadPayload
----------------

.. autoclass:: exorad.tasks.instrumentHandler.LoadPayload
    :members:
    :undoc-members:
    :show-inheritance:

PreparePayload
----------------

.. autoclass:: exorad.tasks.instrumentHandler.PreparePayload
    :members:
    :undoc-members:
    :show-inheritance:

MergeChannelsOutput
-----------------------------

.. autoclass:: exorad.tasks.instrumentHandler.MergeChannelsOutput
    :members:
    :undoc-members:
    :show-inheritance:


GetChannelList
----------------

.. autoclass:: exorad.tasks.instrumentHandler.GetChannelList
    :members:
    :undoc-members:
    :show-inheritance: